<?php
	
	class USEWP_POST
	{
		
		protected $type, $name, $tax, $tax_name;
		
		public function add_all($type, $name, $tax, $tax_name,$select=false,$tags=false)
		{
			$this->add_type($type, $name);
			$this->add_tax($type, $tax, $tax_name,$select,$tags);
			$this->add_link();
			$this->add_rewrites();
		}
		
		public function change_orderby()
		{
			add_action('pre_get_posts', array($this, 'filter_query'));
		}
		
		public function filter_query($query)
		{
			if (is_home() || is_archive() || is_singular()) {
				$query->query_vars['orderby'] = 'menu_order';
				$query->query_vars['order'] = 'DESC';
			}
			return $query;
		}
		
		public function add_type($type, $name)
		{
			$this->type = $type;
			$this->name = $name;
			add_action('init', array($this, 'add_type_init'));
			$this->add_link();
			$this->add_rewrites();
		}
		
		public function add_tax($type, $tax, $tax_name, $select = true,$tags=false)
		{
			$this->type = $type;
			$this->tax = $tax;
			$this->tax_name = $tax_name;
			add_action('init', array($this, 'add_tax_init'));
			if ($select) {
				$this->add_select();
			}
			if($tags){
				add_action('init', array($this, 'add_tags'));
			}
		}
		
		public function add_tags()
		{
			register_taxonomy_for_object_type( 'post_tag', $this->type );
		}
		
		//把自定义类型的文章加入文档流-停用
		public function add_archive($post_type)
		{
			$this->type = $post_type;
			add_filter('pre_get_posts', array($this, 'add_archive_code'));
		}
		
		public function add_archive_code($query)
		{
			$long = get_option('long');
			if (is_home() && !wp_is_mobile() && $long == 'yes') {
				$usewp_type = get_post_types();
				unset($usewp_type['post']);
				unset($usewp_type['page']);
				unset($usewp_type['custom_css']);
				unset($usewp_type['customize_changeset']);
				unset($usewp_type['user_request']);
				unset($usewp_type['oembed_cache']);
				$query->set('post_type', $usewp_type);
			}
			return $query;
		}
		
		
		public function add_select()
		{
			add_action('restrict_manage_posts', array($this, 'add_select_int'));
			$this->add_query();
		}
		
		public function add_query()
		{
			add_filter('parse_query', array($this, 'add_query_init'));
		}
		
		public function add_link()
		{
			add_filter('post_type_link', array($this, 'add_link_init'), 1, 3);
		}
		
		public function add_rewrites()
		{
			add_action('init', array($this, 'add_rewrites_init'));
		}
		
		public function add_tax_init()
		{
			register_taxonomy(
				$this->tax,
				$this->type,
				array(
					'labels' => array(
						'name' => $this->tax_name,
						'add_new' => '新增',
						'add_new_item' => '添加',
						'new_item_name' => "新" . $this->tax_name,
					),
					'show_ui' => true,
					'show_tagcloud' => true,
					'hierarchical' => true,
				)
			);
		}
		
		public function add_type_init()
		{
			register_post_type($this->type,
				array(
					'labels' => array(
						'name' => $this->name,
						'title' => $this->name,
						'singular_name' => '所有' . $this->name,
						'add_new' => '添加' . $this->name,
						'add_new_item' => '添加新' . $this->name,
						'edit' => '编辑',
						'edit_item' => '编辑' . $this->name,
						'new_item' => '新' . $this->name,
						'view' => '查看' . $this->name,
						'view_item' => '查看' . $this->name,
						'search_items' => '搜索' . $this->name,
						'not_found' => '没有找到相关' . $this->name,
						'not_found_in_trash' => '没有' . $this->name . '评论',
						'parent' => $this->name . '评论',
					),
					'exclude_from_search' => false,
					'public' => true,
					'menu_position' => 6,
					'supports' => array(
						'title',
						'editor',
						'comments',
						'custom-fields',
						'thumbnail',
						'excerpt',
						'page-attributes',
						'author'
					),
					'taxonomies' => array(''),
					'has_archive' => true,
				)
			);
		}
		
		public function add_select_int()
		{
			global $typenow;
			global $wp_query;
			if ($typenow == $this->type) {
				return wp_dropdown_categories(array(
					'show_option_all' => $this->tax_name,
					'taxonomy' => $this->tax,
					'name' => $this->tax,
					'orderby' => 'name',
					'selected' => @$wp_query->query[$this->tax],
					'hierarchical' => true,
					'depth' => 5,
					'show_count' => true, // Show # listings in parens
					'hide_empty' => false, // Don't show businesses w/o listings
				));
			}
		}
		
		public function add_query_init($query)
		{
			$qv = &$query->query_vars;
			if (($qv[$this->tax]) && is_numeric($qv[$this->tax])) {
				$term = get_term_by('id', $qv[$this->tax], $this->tax);
				$qv[$this->tax] = $term->slug;
			}
		}
		
		public function add_link_init($link, $post = 0)
		{
			global $user_ID;
			if (!in_array($post->post_type, array('post', 'page'))) {
				return home_url($post->post_type . '/' . $post->ID . '.html');
			} else {
				return $link;
			}
		}
		
		public function add_rewrites_init()
		{
		    // 自定义文章类型的伪静态规则
			add_rewrite_rule(
				$this->type . '/([0-9]+)?.html$',
				'index.php?post_type=' . $this->type . '&p=$matches[1]',
				'top');
			add_rewrite_rule(
				$this->type . '/([0-9]+)?.html/comment-page-([0-9]{1,})$',
				'index.php?post_type=' . $this->type . '&p=$matches[1]&cpage=$matches[2]',
				'top');
			add_rewrite_rule(
				$this->type . '/([0-9]+)?-([0-9]+)?.html$',
				'index.php?post_type=' . $this->type . '&p=$matches[1]&u=$matches[2]',
				'top');
			add_rewrite_rule(
				$this->type . '/([0-9]+)?-([0-9]+)?.html/comment-page-([0-9]{1,})$',
				'index.php?post_type=' . $this->type . '&p=$matches[1]&u=$matches[2]&cpage=$matches[3]',
				'top');
			
			
		}
		
	}

?>